/*
 * File:		FTM_PWM.c
 * Purpose:		Main process
 *
 */

#include "common.h"

#define FTM_12MHZ_PERIOD	(0x00000004UL)
#define FTM_12MHZ_DUTY		(0x00000002UL)

#define FTM_25MHZ_PERIOD	(0x00000002UL)
#define FTM_25MHZ_DUTY		(0x00000001UL)

void vfnFTMEdgeAligned (uint32 u32Period, uint32 u32Duty);

/********************************************************************/
void main (void)
{
	char ch;
        
        vfnFTMEdgeAligned(FTM_12MHZ_PERIOD,FTM_12MHZ_DUTY);
      


	while(1)
	{
		ch = in_char();
		out_char(ch);
	} 
}

/*!
      \fn void vfnFTMEdgeAligned (uint32 u32Period, uint32 u32Duty)
      \brief  Initializes FTM0 for PWM Edge aligned
	  \param  uint32 u32Period: Period for the output
	  \param  uint32 u32Duty: PWM duty cycle
      \return void
*/ 
void vfnFTMEdgeAligned (uint32 u32Period, uint32 u32Duty)
{
	SIM_SCGC6 |= SIM_SCGC6_FTM0_MASK; /* Enable clock for FTM0 */

	PORTC_PCR1 = 0x400; /* FTM0_CH0 enable on PTC1 */
		
	FTM0_MOD = u32Period; /* PWM period */
	
	/* Configure timers for edge aligned PWM High True Pulses */
	
	FTM0_C0SC = 0x28; /* No Interrupts; High True pulses on Edge Aligned PWM */
	
	FTM0_C0V = u32Duty; /* 50% pulse width */  
	
	FTM0_SC = 0x08; /* Edge Aligned PWM running from BUSCLK / 1 */
}
